.. gokart documentation master file, created by
   sphinx-quickstart on Fri Jan 11 07:59:25 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gokart's documentation!
==================================
Getting Started
----------------

Run ``pip instgall gokart`` to install the latest version from PyPI.
`Documentation: <https://gokart.readthedocs.io/en/latest/>`_ for the latest release is hosted on readthedocs.

Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   task_on_kart
   task_information
   task_settings


API References
--------------
.. toctree::
   :maxdepth: 2

   gokart


Indices and tables
-------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
